@@ -292,23 +292,24 @@ impl AppState {
             return Ok(CmdResult::Stay);
         }
 
-
         if key == CONTROL_UP { // moving the selected line up
             if let DrawerEdit(des) = &mut self.drawer_state {
-                des.close_input(false);
                 let entries = &mut des.drawer.content.entries;
                 let len = entries.len();
-                match des.focus {
+                match &mut des.focus {
                     NameSelected { line } => {
-                        let new_line = (line + len - 1) % len;
-                        entries.swap(line, new_line);
+                        let new_line = (*line + len - 1) % len;
+                        entries.swap(*line, new_line);
                         des.focus = NameSelected { line: new_line };
                     }
                     ValueSelected { line } => {
-                        let new_line = (line + len - 1) % len;
-                        entries.swap(line, new_line);
+                        let new_line = (*line + len - 1) % len;
+                        entries.swap(*line, new_line);
                         des.focus = ValueSelected { line: new_line };
                     }
+                    ValueEdit { input, .. }  => {
+                        input.move_current_line_up();
+                    }
                     _ => {}
                 }
                 des.update_search();
@@ -317,20 +318,22 @@ impl AppState {
         }
         if key == CONTROL_DOWN { // moving the selected line down
             if let DrawerEdit(des) = &mut self.drawer_state {
-                des.close_input(false);
                 let entries = &mut des.drawer.content.entries;
                 let len = entries.len();
-                match des.focus {
+                match &mut des.focus {
                     NameSelected { line } => {
-                        let new_line = (line + 1) % len;
-                        entries.swap(line, new_line);
+                        let new_line = (*line + 1) % len;
+                        entries.swap(*line, new_line);
                         des.focus = NameSelected { line: new_line };
                     }
                     ValueSelected { line } => {
-                        let new_line = (line + 1) % len;
-                        entries.swap(line, new_line);
+                        let new_line = (*line + 1) % len;
+                        entries.swap(*line, new_line);
                         des.focus = ValueSelected { line: new_line };
                     }
+                    ValueEdit { input, .. }  => {
+                        input.move_current_line_down();
+                    }
                     _ => {}
                 }
                 des.update_search();
@@ -338,7 +341,6 @@ impl AppState {
             return Ok(CmdResult::Stay);
         }
 
-
         if let DrawerEdit(des) = &mut self.drawer_state {
             // -- pending removal
             if let PendingRemoval { line } = &des.focus {
@@ -376,8 +378,6 @@ impl AppState {
             }
         }
 
-        // --
-
         if key == ENTER {
             self.close_drawer_input(false); // if there's an entry input
             if let DrawerCreation(PasswordInputState { input }) = &mut self.drawer_state {
@@ -470,13 +470,14 @@ impl AppState {
 
         // --- help
 
-        if key == F1 || key == QUESTION { // note that F1 is rarely available in terminals
+        if key == F1 || key == QUESTION || key == SHIFT_QUESTION {
+            // notes:
+            //  - F1 is rarely available in terminals
+            //  - shift-? is here because on Windows on some keyboard I receive it for the ?
             self.help = Some(HelpState::default());
             return Ok(CmdResult::Stay);
         }
 
-        // --- navigation among entries
-
         if let DrawerEdit(des) = &mut self.drawer_state {
             if key == HOME {
                 des.apply_scroll_command(ScrollCommand::Top);
@@ -526,20 +527,42 @@ impl AppState {
 
         if let DrawerEdit(des) = &mut self.drawer_state {
             if key == RIGHT {
-                if let NameSelected { line } = &des.focus {
-                    let line = *line;
-                    des.focus = ValueSelected { line };
-                } else if matches!(des.focus, NoneSelected) {
-                    des.focus = NameSelected { line: 0 };
+                match &des.focus {
+                    SearchEdit { previous_line } => {
+                        // we're here because apply_event on the input returned false,
+                        // which means the right arrow key was ignored because it was
+                        // at the end of the input. We'll assume the user wants to
+                        // select the value of the selected line
+                        if let Some(line) = des.best_search_line() {
+                            des.focus = ValueSelected { line };
+                        } else if let Some(&line) = previous_line.as_ref() {
+                            des.focus = ValueSelected { line };
+                        }
+                    }
+                    NameSelected { line } => {
+                        let line = *line;
+                        des.focus = ValueSelected { line };
+                    }
+                    NoneSelected => {
+                        des.focus = NameSelected { line: 0 };
+                    }
+                    _ => {}
                 }
                 return Ok(CmdResult::Stay);
             }
             if key == LEFT {
-                if let ValueSelected { line } = &des.focus {
-                    let line = *line;
-                    des.focus = NameSelected { line };
-                } else if matches!(des.focus, NoneSelected) {
-                    des.focus = NameSelected { line: 0 };
+                match &des.focus {
+                    NameSelected { .. } => {
+                        des.focus = SearchEdit { previous_line: des.focus.line() };
+                    }
+                    ValueSelected { line } => {
+                        let line = *line;
+                        des.focus = NameSelected { line };
+                    }
+                    NoneSelected => {
+                        des.focus = NameSelected { line: 0 };
+                    }
+                    _ => {}
                 }
                 return Ok(CmdResult::Stay);
             }
@@ -572,7 +595,7 @@ impl AppState {
                     }
                     ('/', _) => {
                         // start searching
-                        des.focus = SearchEdit;
+                        des.focus = SearchEdit { previous_line: des.focus.line() };
                     }
                     _ => {}
                 }
